@@ -263,12 +263,6 @@ intifada::Field_Specification_Data::clone(
     return *this;
   }
 
-void
-intifada::Field_Specification_Data::get_structure()const
-{
-  uap_->get_structure();
-}
-
 uint8_t
 intifada::Field_Specification_Data::get_part(uint8_t o) const
 {
