@@ -308,11 +308,11 @@ std::string XML_Generator::pop_field()
           {
             std::ostringstream &os=*records_.back();
             if(c!=NULL){
-              os << "create_uap_id:"<<c->get_lvalue()<<std::endl;
-              os << "create_uap_frn:"<<c->get_rvalue()<<std::endl;
+              os << "create_uap_id="<<c->get_lvalue()<<std::endl;
+              os << "create_uap_frn="<<c->get_rvalue()<<std::endl;
             }else{
-              os << "create_uap_id:"<<std::endl;
-              os << "create_uap_frn:"<<std::endl;
+              os << "create_uap_id="<<std::endl;
+              os << "create_uap_frn="<<std::endl;
             }
             return 0;
           }
@@ -331,9 +331,9 @@ std::string XML_Generator::pop_field()
               f="true";
             }
             std::ostringstream &os=*records_.back();
-            os << "create_item_longname:"<<longname<<std::endl;
-            os << "create_item_reference:"<<reference<<std::endl;
-            os << "create_item_force:"<<f<<std::endl;
+            os << "create_item_longname="<<longname<<std::endl;
+            os << "create_item_reference="<<reference<<std::endl;
+            os << "create_item_force="<<f<<std::endl;
             return 0;
           }
         int Text_Generator::end_item()
@@ -343,8 +343,8 @@ std::string XML_Generator::pop_field()
         int Text_Generator::frn(int f,const intifada::Path_Name& s)
           {
             std::ostringstream &os=*records_.back();
-            os << "create_frn:" << f << std::endl;
-            os << "create_frn_id:"<<s<<std::endl;
+            os << "create_frn=" << f << std::endl;
+            os << "create_frn_id="<<s<<std::endl;
             return 0;
           }
 
@@ -360,23 +360,23 @@ std::string XML_Generator::pop_field()
             records_.push_back(new std::ostringstream);
             std::ostringstream &os=*records_.back();
 
-            os << "create_record_desc:" << desc << std::endl;
-            os << "create_record_id:" << id << std::endl;
-            os << "create_record_cat:" << static_cast<uint16_t>(c) << std::endl;
-            os << "push_record:"<<std::endl;
+            os << "create_record_desc=" << desc << std::endl;
+            os << "create_record_id=" << id << std::endl;
+            os << "create_record_cat=" << static_cast<uint16_t>(c) << std::endl;
+            os << "push_record="<<std::endl;
             return 0;
           }
         int Text_Generator::end_record_identity()
           {
             std::ostringstream &os=*records_.back();
-            os << "pop_record:"<< std::endl;
+            os << "pop_record="<< std::endl;
             return 0;
           }
 
         int Text_Generator::begin_fixed_field(const Properties& f)
           {
             std::ostringstream &os=*records_.back();
-            os << "create_fixed:" << std::endl;
+            os << "create_fixed=" << std::endl;
             Text_Properties props(os,"set_item_property");
             f.for_each_property(props);
             return 0;
@@ -385,7 +385,7 @@ std::string XML_Generator::pop_field()
         int Text_Generator::begin_extended_field(const Properties& f)
           {
             std::ostringstream &os=*records_.back();
-            os << "create_extended:" << std::endl;
+            os << "create_extended=" << std::endl;
             Text_Properties props(os,"set_item_property");
             if(f.get_property("repetitive")=="true"){
               props.hide("secondaries_size");
@@ -397,7 +397,7 @@ std::string XML_Generator::pop_field()
         int Text_Generator::begin_repetitive_field(const Properties& f)
           {
             std::ostringstream &os=*records_.back();
-            os << "create_repetitive:"<<std::endl;
+            os << "create_repetitive="<<std::endl;
             Text_Properties props(os,"set_item_property");
             f.for_each_property(props);
             return 0;
@@ -406,34 +406,34 @@ std::string XML_Generator::pop_field()
         int Text_Generator::begin_compound_field(uint8_t size)
           {
             std::ostringstream &os=*records_.back();
-            os << "create_compound_size:"<<static_cast<uint16_t>(size)<<std::endl;
-            os << "push_record:"<<std::endl;
+            os << "create_compound_size="<<static_cast<uint16_t>(size)<<std::endl;
+            os << "push_record="<<std::endl;
             return 0;
           }
 
         void Text_Generator::end_compound_field()
           {
             std::ostringstream &os=*records_.back();
-            os << "pop_record:"<< std::endl;
-            os << "end_compound:" << std::endl;
+            os << "pop_record="<< std::endl;
+            os << "end_compound=" << std::endl;
             return;
           }
 
         int Text_Generator::part(const intifada::Type& type,const intifada::Path_Name& name,uint8_t start,uint8_t size,uint8_t part)
           {
             std::ostringstream &os=*records_.back();
-            os << "handle_parts_full_name:"<<name.get_full_name()<<std::endl;
-            os << "handle_parts_type:"<<type.get_name()<<std::endl;
+            os << "handle_parts_full_name="<<name.get_full_name()<<std::endl;
+            os << "handle_parts_type="<<type.get_name()<<std::endl;
             if(part!=intifada::Data_Field_Characteristics_List::npos)
               {
-                os << "handle_parts_byte:"<<static_cast<int16_t>(part) <<std::endl;
+                os << "handle_parts_byte="<<static_cast<int16_t>(part) <<std::endl;
               }
             else
               {
                 os << "handle_parts_byte:-1" <<std::endl;
               }
-            os << "handle_parts_start:"<< static_cast<uint16_t>(start) <<std::endl;
-            os << "handle_parts_size:"<< static_cast<uint16_t>(size) <<std::endl;
+            os << "handle_parts_start="<< static_cast<uint16_t>(start) <<std::endl;
+            os << "handle_parts_size="<< static_cast<uint16_t>(size) <<std::endl;
 
             Text_Properties props(os,"set_type_property");
             type.for_each_property(props);
@@ -443,11 +443,11 @@ std::string XML_Generator::pop_field()
           {
             for(ssv_iterator_t it=families_.begin();it!=families_.end();++it){
               const std::string& family=(*it).first;
-              ccv_ << "create_family:"<< family << std::endl;
+              ccv_ << "create_family="<< family << std::endl;
               sv_t &ids=(*it).second;
               for(sv_iterator_t j=ids.begin();j!=ids.end();++j){
                 std::string& id=(*j);
-                ccv_ << "create_family_id:"<< id << std::endl;
+                ccv_ << "create_family_id="<< id << std::endl;
               }
             }
             std::cout << ccv_.str();
