@@ -19,6 +19,7 @@
 #include <Dump_Operation.hxx>
 #include <intifada/Message.hxx>
 #include <Dump_Iterator.hxx>
+#include <iostream>
 
 Dump_Operation::Dump_Operation(intifada::Record_Repository* rep,const std::string& dump_type):inherited(rep),dump_type_(dump_type){}
 
@@ -27,15 +28,21 @@ int Dump_Operation::operator()(
     const std::string&,
     const uint8_t*m,
     uint16_t msg_size,
-    const std::string&)
-    throw(intifada::Parsing_Input_Length_Exception)
+    const std::string&,
+    void* userdata)
+    throw(intifada::Parsing_Input_Length_Exception,intifada::Parsing_Unknow_Category)
     {
+  std::ostream& os=std::cout;
 
+  if(userdata!=NULL)
+    {
+    os << *static_cast<std::string *>(userdata) << std::endl;
+    }
   intifada::Message msg(rep_,family);
 
   intifada::Stream::size_type s;
   s = msg.set_stream(m,0,msg_size);
-  Dump_Iterator cit;
+  Dump_Iterator cit(os);
   if(dump_type_=="ALL"){
     cit.dump_all();
   }
